@@ -6,6 +6,7 @@ from .models import DBData
 from .models import Station
 from .models import ServerInstance
 from .models import DataDestiny
+from .models import NetworkGroup
 from .manager import SessionHandle
 from .manager import SessionCollector
 from .manager import SessionDataWork
@@ -14,5 +15,6 @@ from .load_data import load_protocol
 from .load_data import load_dbdata
 from .load_data import load_dbtype
 from .load_data import load_server
+from .load_data import load_network
 from .load_data import load_station
 
