@@ -21,7 +21,7 @@ from sqlalchemy.sql import select
 from sqlalchemy.sql import table
 from sqlalchemy.sql import column
 from sqlalchemy import inspect
-
+from rich import print
 
 def object_as_dict(obj):
     return {c.key: getattr(obj, c.key)
@@ -177,7 +177,7 @@ class SessionHandle(CollectorSession):
         up = update(table).where(
             table.c.id == instance.id).values({field_name: value})
         self.session.execute(up)
-        self.session.commit()
+        result = self.session.commit()
 
     # LIST ELEMENTS
 
@@ -204,6 +204,7 @@ class SessionCollector(SH):
     # STATION TABLE
 
     def station(self,
+                refresh=True,
                 **kwargs):
         code = kwargs.get('code')
         name = kwargs.get('name')
@@ -220,8 +221,11 @@ class SessionCollector(SH):
         active = kwargs.get('active', False)
         network = kwargs.get("network_id","3g")
         instance = self.session.query(Station).filter_by(code=code).first()
+
         if instance:
             self.logger.info("Estación %s ya existe" % instance)
+            if refresh:
+                return self.update_station(instance, kwargs)
             return instance
         else:
             try:
@@ -283,38 +287,94 @@ class SessionCollector(SH):
         self.session.add(station)
         self.session.commit()
 
-    def update_station(self, instance, new_dict):
+    def update_station(self, instance, kwargs):
+        differences = {}
         t_name = 'station'
-        station = object_as_dict(instance)
-        db = None
-        protocol = None
-        if 'db' in new_dict.keys():
-            db = new_dict['db']
-        if 'protocol' in new_dict.keys():
-            protocol = new_dict['protocol']
-        db_e = object
-        prot_e = object
-        if db:
-            if isinstance(db, int):
-                db_e = self.get_dbdata_by_id(db)
-                db_id = db_e.id
-            else:
-                db_e = self.get_dbdata_id(db)
-                db_id = db_e.id
-        if protocol:
-            if isinstance(protocol, int):
-                prot_e = self.get_protocol_by_id(protocol)
-                prot_id = prot_e.id
-            else:
-                prot_e = self.get_protocol_id(protocol)
-                prot_id = prot_e.id
-            new_dict['protocol_id'] = prot_id
-            new_dict['db_id'] = db_id
-        for k in new_dict.keys():
-            print(k)
-            if k in station.keys():
-                v = new_dict[k]
-                self.update_table(t_name, instance, k, v)
+        code = kwargs.get('code')
+        name = kwargs.get('name')
+        position_x = kwargs.get('ECEF_X')
+        position_y = kwargs.get('ECEF_Y')
+        position_z = kwargs.get('ECEF_Z')
+        protocol_host = kwargs.get('protocol_host')
+        host = kwargs.get('host')
+        port = int(kwargs.get('port'))
+        interface_port = int(kwargs.get('interface_port'))
+        db = kwargs.get('db')
+        protocol = kwargs.get('protocol')
+        server = kwargs.get('server_id', "atlas")
+        active = kwargs.get('active', False)
+        network = kwargs.get("network_id","3g")
+        position_x = kwargs.get('ECEF_X')
+        position_y = kwargs.get('ECEF_Y')
+        position_z = kwargs.get('ECEF_Z')
+
+        point = dict(X=position_x, Y=position_y, Z=position_z)
+        # check if db and protocol exists
+        db_id = None
+        prot_id = None
+        network_id = None
+        if isinstance(db, int):
+            db_e = self.get_dbdata_by_id(db)
+            db_id = db_e.id
+        else:
+            db_e = self.get_dbdata_id(db)
+            db_id = db_e.id
+        kwargs["db_id"] = db_id
+
+        if isinstance(protocol, int):
+            prot_e = self.get_protocol_by_id(protocol.upper())
+            prot_id = prot_e.id
+        else:
+
+            prot_e = self.get_protocol_id(protocol)
+            prot_id = prot_e.id
+        kwargs["protocol_id"] = prot_id
+
+        if isinstance(server, str) and not server.isdigit():
+            server_e = self.get_server_id(server.upper())
+            server_id = server_e.id
+        elif server.isdigit():
+            server_e = self.get_server_by_id(server)
+            server_id = server_e.id
+        kwargs["server_id"] = server_id
+
+        if isinstance(network, int):
+            network_e = self.get_network_by_id(network.upper())
+            network_id = network_e.id
+        else:
+            network_e = self.get_network_id(network)
+            network_id = network_e.id
+        kwargs["network_id"] = server_id
+
+        if db_e and prot_e:
+            station = Station(code=code,
+                              name=name,
+                              position_x=point['X'],
+                              position_y=point['Y'],
+                              position_z=point['Z'],
+                              interface_port=interface_port,
+                              protocol_host=protocol_host,
+                              port=port,
+                              host=host,
+                              db_id=db_id,
+                              protocol_id=prot_id,
+                              active=active,
+                              server_id=server_id,
+                              network_id=network_id)
+
+            for k, v in station.json.items():
+                val = instance.json.get(k)
+                if val:
+                    if v != val and k!='id':
+                        if k.startswith('ECEF'):
+                            key = k.replace("ECEF", "position").lower()
+                            differences[key] = v
+                        else:
+                            differences[k] = v
+            for k, v in differences.items():
+                if k in station.json.keys():
+                    self.update_table(t_name, instance, k, v)
+        return instance
 
     def delete_station(self, station):
         self.session.delete(station)
@@ -370,7 +430,6 @@ class SessionCollector(SH):
         sql_query = sql_query_tpl.replace("[SERVER_ID]",
                                           str(server.id)).replace("[ACTIVE]", active)
         file_q.close()
-        print("Consulta--->", sql_query)
         stmt = text(sql_query)
         result = self.session.execute(stmt)
         return result
