@@ -44,6 +44,11 @@ class Protocol(Base):
     def validate_url(self, key, value):
         return value if validURL(value) else "localhost"
 
+    def __repr__(self):
+        return f"Procotol({self.id} {self.name})"
+
+    def __str__(self):
+        return f"Procotol({self.id} {self.name})"
 
 class DBType(Base):
     """
@@ -98,6 +103,12 @@ class DBData(Base):
     def validate_host(self, key, value):
         return value if validURL(value) else "localhost"
 
+    def __str__(self):
+        return f"DBData({self.code}:{self.dbname}:{self.host}:{self.port})"
+
+    def __repr__(self):
+        return f"DBData({self.code}:{self.dbname}:{self.host}:{self.port})"
+
 
 class Station(Base):
     """
@@ -163,6 +174,26 @@ class Station(Base):
         point = dict(X=self.position_x, Y=self.position_y, Z=self.position_z)
         return point  # list(point.coords)
 
+    @property
+    def json(self):
+        return {
+            "id": self.id, 
+            "code": self.code,
+            "name": self.name,
+            "ECEF_X": float(self.position_x),
+            "ECEF_Y": float(self.position_y),
+            "ECEF_Z": float(self.position_z),
+            "interface_port": self.interface_port,
+            "host": self.host,
+            "protocol_host": self.protocol_host,
+            "port": self.port,
+            "active": self.active,
+            "db_id": self.db_id,
+            "protocol_id": self.protocol_id,
+            "server_id": self.server_id,
+            "network_id": self.network_id
+        }
+
 
 class NetworkGroup(Base):
     __tablename__ = 'network_group'
